
CREATE TABLE Customer (
       customer_id          INTEGER NOT NULL,
       first_name           VARCHAR(20),
       last_name            VARCHAR(20),
       street               VARCHAR(20),
       city                 VARCHAR(20),
       state                VARCHAR(20),
       zip                  INTEGER,
       phone                INTEGER,
       gender               VARCHAR(20),
       date_of_birth        DATE,
       comments             VARCHAR(20)
);

CREATE UNIQUE INDEX XPKCustomer ON Customer
(
       customer_id                    ASC
);


ALTER TABLE Customer
       ADD PRIMARY KEY (customer_id);


CREATE TABLE Drug_Company (
       drug_company_id      INTEGER NOT NULL,
       drug_company_name    VARCHAR(20),
       phone                INTEGER
);

CREATE UNIQUE INDEX XPKDrug_Company ON Drug_Company
(
       drug_company_id                ASC
);


ALTER TABLE Drug_Company
       ADD PRIMARY KEY (drug_company_id);


CREATE TABLE Ingredient (
       ingredient_id        INTEGER NOT NULL,
       ingredient_name      VARCHAR(20)
);

CREATE UNIQUE INDEX XPKIngredient ON Ingredient
(
       ingredient_id                  ASC
);


ALTER TABLE Ingredient
       ADD PRIMARY KEY (ingredient_id);


CREATE TABLE Insurance_Policy (
       policy_id            INTEGER NOT NULL,
       customer_id          INTEGER NOT NULL,
       insurance_company    VARCHAR(20),
       company_phone        INTEGER,
       copayment            INTEGER
);

CREATE UNIQUE INDEX XPKInsurance_Polic ON Insurance_Policy
(
       policy_id                      ASC
);


ALTER TABLE Insurance_Policy
       ADD PRIMARY KEY (policy_id);


CREATE TABLE Medicine (
       medicine_id          INTEGER NOT NULL,
       precautions          VARCHAR(20),
       ingredients          VARCHAR(20),
       indications          VARCHAR(20),
       shelf_life           VARCHAR(20),
       side_effects         VARCHAR(20),
       name                 VARCHAR(20),
       drug_company         VARCHAR(20),
       type                 VARCHAR(20),
       price                INTEGER,
       drug_company_id      INTEGER,
       prescription_id      INTEGER,
       branch_id            INTEGER
);

CREATE UNIQUE INDEX XPKMedicine ON Medicine
(
       medicine_id                    ASC
);


ALTER TABLE Medicine
       ADD PRIMARY KEY (medicine_id);


CREATE TABLE Medicine_Ingredien (
       medicine_id          INTEGER NOT NULL,
       ingredient_id        INTEGER NOT NULL
);

CREATE UNIQUE INDEX XPKMedicine_Ingred ON Medicine_Ingredien
(
       medicine_id                    ASC,
       ingredient_id                  ASC
);


ALTER TABLE Medicine_Ingredien
       ADD PRIMARY KEY (medicine_id, ingredient_id);


CREATE TABLE Medicine_Side_Effe (
       medicine_id          INTEGER NOT NULL,
       side_effect_id       INTEGER NOT NULL
);

CREATE UNIQUE INDEX XPKMedicine_Side_E ON Medicine_Side_Effe
(
       medicine_id                    ASC,
       side_effect_id                 ASC
);


ALTER TABLE Medicine_Side_Effe
       ADD PRIMARY KEY (medicine_id, side_effect_id);


CREATE TABLE Medicine_Symptom (
       medicine_id          INTEGER NOT NULL,
       symptom_id           INTEGER NOT NULL
);

CREATE UNIQUE INDEX XPKMedicine_Sympto ON Medicine_Symptom
(
       medicine_id                    ASC,
       symptom_id                     ASC
);


ALTER TABLE Medicine_Symptom
       ADD PRIMARY KEY (medicine_id, symptom_id);


CREATE TABLE Order (
       order_id             INTEGER NOT NULL,
       pharmacist_id        INTEGER NOT NULL,
       order_date           DATE,
       pickup_date          DATE,
       cost                 INTEGER,
       refill_number        INTEGER,
       prescription_id      INTEGER
);

CREATE UNIQUE INDEX XPKOrder ON Order
(
       order_id                       ASC
);


ALTER TABLE Order
       ADD PRIMARY KEY (order_id);


CREATE TABLE Pharmacist (
       pharmacist_id        INTEGER NOT NULL,
       branch_id            INTEGER NOT NULL,
       first_name           VARCHAR(20),
       last_name            VARCHAR(20),
       title                VARCHAR(20),
       street               VARCHAR(20),
       city                 VARCHAR(20),
       state                VARCHAR(20),
       zip                  INTEGER,
       phone                INTEGER
);

CREATE UNIQUE INDEX XPKPharmacist ON Pharmacist
(
       pharmacist_id                  ASC
);


ALTER TABLE Pharmacist
       ADD PRIMARY KEY (pharmacist_id);


CREATE TABLE Pharmacy_Branch (
       branch_id            INTEGER NOT NULL,
       pharmacy_name        VARCHAR(20),
       street               VARCHAR(20),
       city                 CHAR(18),
       state                VARCHAR(20),
       zip                  VARCHAR(20),
       phone                VARCHAR(20),
       hours                VARCHAR(20),
       comments             VARCHAR(20),
       medicine_id          INTEGER
);

CREATE UNIQUE INDEX XPKPharmacy_Branch ON Pharmacy_Branch
(
       branch_id                      ASC
);


ALTER TABLE Pharmacy_Branch
       ADD PRIMARY KEY (branch_id);


CREATE TABLE Pharmacy_Medicine_ (
       quantity             INTEGER,
       branch_id            INTEGER NOT NULL,
       medicine_id          INTEGER NOT NULL
);

CREATE UNIQUE INDEX XPKPharmacy_Medici ON Pharmacy_Medicine_
(
       medicine_id                    ASC,
       branch_id                      ASC
);


ALTER TABLE Pharmacy_Medicine_
       ADD PRIMARY KEY (medicine_id, branch_id);


CREATE TABLE Physician (
       physician_id         INTEGER NOT NULL,
       street               VARCHAR(20),
       city                 VARCHAR(20),
       state                VARCHAR(20),
       zip                  INTEGER,
       phone                INTEGER,
       first_name           VARCHAR(20),
       last_name            VARCHAR(20),
       specialty            VARCHAR(20),
       insurance_companie   VARCHAR(20)
);

CREATE UNIQUE INDEX XPKPhysician ON Physician
(
       physician_id                   ASC
);


ALTER TABLE Physician
       ADD PRIMARY KEY (physician_id);


CREATE TABLE Prescription (
       prescription_id      INTEGER NOT NULL,
       customer_id          INTEGER NOT NULL,
       physician_id         INTEGER NOT NULL,
       prescription_date    DATE
);

CREATE UNIQUE INDEX XPKPrescription ON Prescription
(
       prescription_id                ASC
);


ALTER TABLE Prescription
       ADD PRIMARY KEY (prescription_id);


CREATE TABLE Prescription_Detai (
       number_refills       INTEGER,
       quantity             INTEGER,
       comments             VARCHAR(20),
       prescription_id      INTEGER NOT NULL,
       dosage               VARCHAR(20)
);

CREATE UNIQUE INDEX XPKPrescription_De ON Prescription_Detai
(
       prescription_id                ASC
);


ALTER TABLE Prescription_Detai
       ADD PRIMARY KEY (prescription_id);


CREATE TABLE Side_Effect (
       side_effect_id       INTEGER NOT NULL,
       side_effect_name     VARCHAR(20)
);

CREATE UNIQUE INDEX XPKSide_Effect ON Side_Effect
(
       side_effect_id                 ASC
);


ALTER TABLE Side_Effect
       ADD PRIMARY KEY (side_effect_id);


CREATE TABLE Symptom (
       symptom_id           INTEGER NOT NULL,
       symptom_name         VARCHAR(20)
);

CREATE UNIQUE INDEX XPKSymptom ON Symptom
(
       symptom_id                     ASC
);


ALTER TABLE Symptom
       ADD PRIMARY KEY (symptom_id);


ALTER TABLE Insurance_Policy
       ADD FOREIGN KEY (customer_id)
                             REFERENCES Customer
                             ON DELETE SET NULL;


ALTER TABLE Medicine
       ADD FOREIGN KEY (drug_company_id)
                             REFERENCES Drug_Company
                             ON DELETE SET NULL;


ALTER TABLE Medicine
       ADD FOREIGN KEY (prescription_id)
                             REFERENCES Prescription_Detai
                             ON DELETE SET NULL;


ALTER TABLE Medicine
       ADD FOREIGN KEY (medicine_id, branch_id)
                             REFERENCES Pharmacy_Medicine_
                             ON DELETE SET NULL;


ALTER TABLE Medicine_Ingredien
       ADD FOREIGN KEY (ingredient_id)
                             REFERENCES Ingredient
                             ON DELETE SET NULL;


ALTER TABLE Medicine_Ingredien
       ADD FOREIGN KEY (medicine_id)
                             REFERENCES Medicine
                             ON DELETE SET NULL;


ALTER TABLE Medicine_Side_Effe
       ADD FOREIGN KEY (side_effect_id)
                             REFERENCES Side_Effect
                             ON DELETE SET NULL;


ALTER TABLE Medicine_Side_Effe
       ADD FOREIGN KEY (medicine_id)
                             REFERENCES Medicine
                             ON DELETE SET NULL;


ALTER TABLE Medicine_Symptom
       ADD FOREIGN KEY (symptom_id)
                             REFERENCES Symptom
                             ON DELETE SET NULL;


ALTER TABLE Medicine_Symptom
       ADD FOREIGN KEY (medicine_id)
                             REFERENCES Medicine
                             ON DELETE SET NULL;


ALTER TABLE Order
       ADD FOREIGN KEY (prescription_id)
                             REFERENCES Prescription
                             ON DELETE SET NULL;


ALTER TABLE Order
       ADD FOREIGN KEY (pharmacist_id)
                             REFERENCES Pharmacist
                             ON DELETE SET NULL;


ALTER TABLE Pharmacist
       ADD FOREIGN KEY (branch_id)
                             REFERENCES Pharmacy_Branch
                             ON DELETE SET NULL;


ALTER TABLE Pharmacy_Branch
       ADD FOREIGN KEY (medicine_id, branch_id)
                             REFERENCES Pharmacy_Medicine_
                             ON DELETE SET NULL;


ALTER TABLE Prescription
       ADD FOREIGN KEY (physician_id)
                             REFERENCES Physician
                             ON DELETE SET NULL;


ALTER TABLE Prescription
       ADD FOREIGN KEY (customer_id)
                             REFERENCES Customer
                             ON DELETE SET NULL;


ALTER TABLE Prescription_Detai
       ADD FOREIGN KEY (prescription_id)
                             REFERENCES Prescription
                             ON DELETE SET NULL;



