
CREATE TABLE Customer (
       customer_id          int NOT NULL,
       first_name           varchar(20) NULL,
       last_name            varchar(20) NULL,
       street               varchar(20) NULL,
       city                 varchar(20) NULL,
       state                varchar(20) NULL,
       zip                  int NULL,
       phone                int NULL,
       gender               varchar(20) NULL,
       date_of_birth        datetime NULL,
       comments             varchar(20) NULL
)
go


ALTER TABLE Customer
       ADD PRIMARY KEY (customer_id)
go


CREATE TABLE Drug_Company (
       drug_company_id      int NOT NULL,
       drug_company_name    varchar(20) NULL,
       phone                int NULL
)
go


ALTER TABLE Drug_Company
       ADD PRIMARY KEY (drug_company_id)
go


CREATE TABLE Ingredient (
       ingredient_id        int NOT NULL,
       ingredient_name      varchar(20) NULL
)
go


ALTER TABLE Ingredient
       ADD PRIMARY KEY (ingredient_id)
go


CREATE TABLE Insurance_Policy (
       policy_id            int NOT NULL,
       customer_id          int NOT NULL,
       insurance_company    varchar(20) NULL,
       company_phone        int NULL,
       copayment            int NULL
)
go


ALTER TABLE Insurance_Policy
       ADD PRIMARY KEY (policy_id)
go


CREATE TABLE Medicine (
       medicine_id          int NOT NULL,
       precautions          varchar(20) NULL,
       ingredients          varchar(20) NULL,
       indications          varchar(20) NULL,
       shelf_life           varchar(20) NULL,
       side_effects         varchar(20) NULL,
       name                 varchar(20) NULL,
       drug_company         varchar(20) NULL,
       type                 varchar(20) NULL,
       price                int NULL,
       drug_company_id      int NULL,
       prescription_id      int NULL,
       branch_id            int NULL
)
go


ALTER TABLE Medicine
       ADD PRIMARY KEY (medicine_id)
go


CREATE TABLE Medicine_Ingredien (
       medicine_id          int NOT NULL,
       ingredient_id        int NOT NULL
)
go


ALTER TABLE Medicine_Ingredien
       ADD PRIMARY KEY (medicine_id, ingredient_id)
go


CREATE TABLE Medicine_Side_Effe (
       medicine_id          int NOT NULL,
       side_effect_id       int NOT NULL
)
go


ALTER TABLE Medicine_Side_Effe
       ADD PRIMARY KEY (medicine_id, side_effect_id)
go


CREATE TABLE Medicine_Symptom (
       medicine_id          int NOT NULL,
       symptom_id           int NOT NULL
)
go


ALTER TABLE Medicine_Symptom
       ADD PRIMARY KEY (medicine_id, symptom_id)
go


CREATE TABLE Order (
       order_id             int NOT NULL,
       pharmacist_id        int NOT NULL,
       order_date           datetime NULL,
       pickup_date          datetime NULL,
       cost                 int NULL,
       refill_number        int NULL,
       prescription_id      int NULL
)
go


ALTER TABLE Order
       ADD PRIMARY KEY (order_id)
go


CREATE TABLE Pharmacist (
       pharmacist_id        int NOT NULL,
       branch_id            int NOT NULL,
       first_name           varchar(20) NULL,
       last_name            varchar(20) NULL,
       title                varchar(20) NULL,
       street               varchar(20) NULL,
       city                 varchar(20) NULL,
       state                varchar(20) NULL,
       zip                  int NULL,
       phone                int NULL
)
go


ALTER TABLE Pharmacist
       ADD PRIMARY KEY (pharmacist_id)
go


CREATE TABLE Pharmacy_Branch (
       branch_id            int NOT NULL,
       pharmacy_name        varchar(20) NULL,
       street               varchar(20) NULL,
       city                 char(18) NULL,
       state                varchar(20) NULL,
       zip                  varchar(20) NULL,
       phone                varchar(20) NULL,
       hours                varchar(20) NULL,
       comments             varchar(20) NULL,
       medicine_id          int NULL
)
go


ALTER TABLE Pharmacy_Branch
       ADD PRIMARY KEY (branch_id)
go


CREATE TABLE Pharmacy_Medicine_ (
       quantity             int NULL,
       branch_id            int NOT NULL,
       medicine_id          int NOT NULL
)
go


ALTER TABLE Pharmacy_Medicine_
       ADD PRIMARY KEY (medicine_id, branch_id)
go


CREATE TABLE Physician (
       physician_id         int NOT NULL,
       street               varchar(20) NULL,
       city                 varchar(20) NULL,
       state                varchar(20) NULL,
       zip                  int NULL,
       phone                int NULL,
       first_name           varchar(20) NULL,
       last_name            varchar(20) NULL,
       specialty            varchar(20) NULL,
       insurance_companies  varchar(20) NULL
)
go


ALTER TABLE Physician
       ADD PRIMARY KEY (physician_id)
go


CREATE TABLE Prescription (
       prescription_id      int NOT NULL,
       customer_id          int NOT NULL,
       physician_id         int NOT NULL,
       prescription_date    datetime NULL
)
go


ALTER TABLE Prescription
       ADD PRIMARY KEY (prescription_id)
go


CREATE TABLE Prescription_Detai (
       number_refills       int NULL,
       quantity             int NULL,
       comments             varchar(20) NULL,
       prescription_id      int NOT NULL,
       dosage               varchar(20) NULL
)
go


ALTER TABLE Prescription_Detai
       ADD PRIMARY KEY (prescription_id)
go


CREATE TABLE Side_Effect (
       side_effect_id       int NOT NULL,
       side_effect_name     varchar(20) NULL
)
go


ALTER TABLE Side_Effect
       ADD PRIMARY KEY (side_effect_id)
go


CREATE TABLE Symptom (
       symptom_id           int NOT NULL,
       symptom_name         varchar(20) NULL
)
go


ALTER TABLE Symptom
       ADD PRIMARY KEY (symptom_id)
go


ALTER TABLE Insurance_Policy
       ADD FOREIGN KEY (customer_id)
                             REFERENCES Customer
go


ALTER TABLE Medicine
       ADD FOREIGN KEY (drug_company_id)
                             REFERENCES Drug_Company
go


ALTER TABLE Medicine
       ADD FOREIGN KEY (prescription_id)
                             REFERENCES Prescription_Detai
go


ALTER TABLE Medicine
       ADD FOREIGN KEY (medicine_id, branch_id)
                             REFERENCES Pharmacy_Medicine_
go


ALTER TABLE Medicine_Ingredien
       ADD FOREIGN KEY (ingredient_id)
                             REFERENCES Ingredient
go


ALTER TABLE Medicine_Ingredien
       ADD FOREIGN KEY (medicine_id)
                             REFERENCES Medicine
go


ALTER TABLE Medicine_Side_Effe
       ADD FOREIGN KEY (side_effect_id)
                             REFERENCES Side_Effect
go


ALTER TABLE Medicine_Side_Effe
       ADD FOREIGN KEY (medicine_id)
                             REFERENCES Medicine
go


ALTER TABLE Medicine_Symptom
       ADD FOREIGN KEY (symptom_id)
                             REFERENCES Symptom
go


ALTER TABLE Medicine_Symptom
       ADD FOREIGN KEY (medicine_id)
                             REFERENCES Medicine
go


ALTER TABLE Order
       ADD FOREIGN KEY (prescription_id)
                             REFERENCES Prescription
go


ALTER TABLE Order
       ADD FOREIGN KEY (pharmacist_id)
                             REFERENCES Pharmacist
go


ALTER TABLE Pharmacist
       ADD FOREIGN KEY (branch_id)
                             REFERENCES Pharmacy_Branch
go


ALTER TABLE Pharmacy_Branch
       ADD FOREIGN KEY (medicine_id, branch_id)
                             REFERENCES Pharmacy_Medicine_
go


ALTER TABLE Prescription
       ADD FOREIGN KEY (physician_id)
                             REFERENCES Physician
go


ALTER TABLE Prescription
       ADD FOREIGN KEY (customer_id)
                             REFERENCES Customer
go


ALTER TABLE Prescription_Detai
       ADD FOREIGN KEY (prescription_id)
                             REFERENCES Prescription
go



