CREATE TABLE SUPPLIERS (
       SUPPLIER_ID          NUMBER(4) NOT NULL,
       SUPPLIER_NAME        VARCHAR2(80) NULL,
       CONTACT_NAME         VARCHAR2(30) NULL,
       URL                  VARCHAR2(255) NULL,
       PHONE                VARCHAR2(15) NULL,
       ADDR_LINE            VARCHAR2(80) NULL,
       CITY                 VARCHAR2(30) NULL,
       STATE                VARCHAR2(30) NULL,
       ZIP_CODE             VARCHAR2(9) NULL,
       STATUS               CHAR(1) NULL,
       PERFERRED            CHAR(1) NULL,
       COMMENTS             VARCHAR2(1024) NULL
);


ALTER TABLE SUPPLIERS
       ADD  ( PRIMARY KEY (SUPPLIER_ID) ) ;


CREATE TABLE SHIPMENT_METHOD (
       SHIPMENT_METHOD_ID   NUMBER(2) NOT NULL,
       SHIPMENT_DESCRIPTION VARCHAR2(80) NULL
);


ALTER TABLE SHIPMENT_METHOD
       ADD  ( PRIMARY KEY (SHIPMENT_METHOD_ID) ) ;


CREATE TABLE DEPARTMENTS (
       DEPARTMENT_ID        NUMBER(2) NOT NULL,
       DEPARTMENT_NAME      VARCHAR2(20) NULL,
       CITY                 VARCHAR2(30) NULL,
       STATE                CHAR(2) NULL
);


ALTER TABLE DEPARTMENTS
       ADD  ( PRIMARY KEY (DEPARTMENT_ID) ) ;


CREATE TABLE JOBS (
       JOB_ID               NUMBER(2) NOT NULL,
       JOB_DESCRIPTION      VARCHAR2(80) NULL
);


ALTER TABLE JOBS
       ADD  ( PRIMARY KEY (JOB_ID) ) ;


CREATE TABLE EMPLOYEES (
       EMPLOYEE_ID          NUMBER(4) NOT NULL,
       FIRST_NAME           VARCHAR2(20) NULL,
       LAST_NAME            VARCHAR2(20) NULL,
       JOB_ID               NUMBER(2) NULL,
       MANAGER_ID           NUMBER(4) NULL,
       HIRE_DATE            DATE NULL,
       SALARY               NUMBER NULL,
       DEPARTMENT_ID        NUMBER(2) NULL
);


ALTER TABLE EMPLOYEES
       ADD  ( PRIMARY KEY (EMPLOYEE_ID) ) ;


CREATE TABLE SALES_COMMISSION (
       EMPLOYEE_ID          NUMBER(4) NOT NULL,
       COMMISSION           NUMBER NULL
);


ALTER TABLE SALES_COMMISSION
       ADD  ( PRIMARY KEY (EMPLOYEE_ID) ) ;


CREATE TABLE PROMOTIONS (
       PROMOTION_ID         NUMBER(2) NOT NULL,
       PROMOTION_DESC       VARCHAR2(80) NULL,
       PROMOTION_TYPE       VARCHAR2(20) NULL
);


ALTER TABLE PROMOTIONS
       ADD  ( PRIMARY KEY (PROMOTION_ID) ) ;


CREATE TABLE CATEGORIES (
       CATEGORY_ID          NUMBER(2) NOT NULL,
       CATEGORY_NAME        VARCHAR2(80) NULL
);


ALTER TABLE CATEGORIES
       ADD  ( PRIMARY KEY (CATEGORY_ID) ) ;


CREATE TABLE PRODUCTS (
       PRODUCT_ID           NUMBER(4) NOT NULL,
       CATEGORY_ID          NUMBER(2) NULL,
       PRODUCT_NAME         VARCHAR2(80) NULL,
       PRODUCT_DESC         VARCHAR2(512) NULL,
       STATUS               CHAR(1) NULL,
       COMMENTS             VARCHAR2(1024) NULL
);


ALTER TABLE PRODUCTS
       ADD  ( PRIMARY KEY (PRODUCT_ID) ) ;


CREATE TABLE PRODUCT_SUPPLIER (
       PRODUCT_ID           NUMBER(4) NOT NULL,
       SUPPLIER_ID          NUMBER(4) NOT NULL
);


ALTER TABLE PRODUCT_SUPPLIER
       ADD  ( PRIMARY KEY (PRODUCT_ID, SUPPLIER_ID) ) ;


CREATE TABLE PRODUCT_PRICES (
       PRODUCT_ID           NUMBER(4) NOT NULL,
       LIST_PRICE           NUMBER NULL,
       MIN_PRICE            NUMBER NULL,
       MAX_PRICE            NUMBER NULL,
       PURCHASED_PRICE      NUMBER NULL,
       START_DATE           DATE NOT NULL,
       END_DATE             DATE NULL,
       PROMOTION_ID         NUMBER(2) NULL
);


ALTER TABLE PRODUCT_PRICES
       ADD  ( PRIMARY KEY (PRODUCT_ID, START_DATE) ) ;


CREATE TABLE PRODUCT_INVENTORY (
       PRODUCT_ID           NUMBER(4) NOT NULL,
       QTY_ON_HAND          NUMBER NULL,
       QTY_ON_ORDER         NUMBER NULL,
       DATE_ORDERED         DATE NULL,
       DELIVERY_DATE        DATE NULL
);


ALTER TABLE PRODUCT_INVENTORY
       ADD  ( PRIMARY KEY (PRODUCT_ID) ) ;


CREATE TABLE PAYMENT_METHOD (
       PAYMENT_METHOD_ID    NUMBER(2) NOT NULL,
       PAYMENT_DESCRIPTION  VARCHAR2(80) NULL
);


ALTER TABLE PAYMENT_METHOD
       ADD  ( PRIMARY KEY (PAYMENT_METHOD_ID) ) ;


CREATE TABLE CUSTOMERS (
       SALES_REP_ID         NUMBER(4) NULL,
       CUSTOMER_ID          NUMBER(8) NOT NULL,
       CUSTOMER_SSN         VARCHAR2(9) NULL,
       FIRST_NAME           VARCHAR2(20) NULL,
       LAST_NAME            VARCHAR2(20) NULL,
       ADDR_LINE            VARCHAR2(80) NULL,
       CITY                 VARCHAR2(30) NULL,
       STATE                VARCHAR2(30) NULL,
       ZIP_CODE             VARCHAR2(9) NULL,
       PHONE                VARCHAR2(15) NULL,
       EMAIL                VARCHAR2(80) NULL,
       CC_NUMBER            VARCHAR2(20) NULL,
       CREDIT_LIMIT         NUMBER NULL,
       GENDER               CHAR(1) NULL,
       STATUS               CHAR(1) NULL,
       COMMENTS             VARCHAR2(1024) NULL
);


ALTER TABLE CUSTOMERS
       ADD  ( PRIMARY KEY (CUSTOMER_ID) ) ;


CREATE TABLE ORDERS (
       ORDER_ID             NUMBER(5) NOT NULL,
       ORDER_DATE           DATE NULL,
       CUSTOMER_ID          NUMBER(8) NULL,
       EMPLOYEE_ID          NUMBER(4) NULL,
       SHIP_DATE            DATE NULL,
       SHIPMENT_METHOD_ID   NUMBER(2) NULL,
       PAYMENT_METHOD_ID    NUMBER(2) NULL,
       PAID                 CHAR(1) NULL,
       ORDER_STATUS         CHAR(1) NULL,
       COMMENTS             VARCHAR2(1024) NULL
);


ALTER TABLE ORDERS
       ADD  ( PRIMARY KEY (ORDER_ID) ) ;


CREATE TABLE ORDER_LINES (
       ORDER_ID             NUMBER(5) NOT NULL,
       PRODUCT_ID           NUMBER(4) NOT NULL,
       ACTUAL_PRICE         NUMBER NULL,
       DISCOUNT             NUMBER NULL,
       QUANTITY             NUMBER NULL,
       TOTAL_AMOUNT         NUMBER NULL
);


ALTER TABLE ORDER_LINES
       ADD  ( PRIMARY KEY (ORDER_ID, PRODUCT_ID) ) ;


CREATE TABLE EMPLOYEE_RANKS (
       RANK                 NUMBER(2) NOT NULL,
       LO_SAL               NUMBER NULL,
       HI_SAL               NUMBER NULL
);


ALTER TABLE EMPLOYEE_RANKS
       ADD  ( PRIMARY KEY (RANK) ) ;


ALTER TABLE EMPLOYEES
       ADD  ( FOREIGN KEY (DEPARTMENT_ID)
                             REFERENCES DEPARTMENTS ) ;


ALTER TABLE EMPLOYEES
       ADD  ( FOREIGN KEY (JOB_ID)
                             REFERENCES JOBS ) ;


ALTER TABLE SALES_COMMISSION
       ADD  ( FOREIGN KEY (EMPLOYEE_ID)
                             REFERENCES EMPLOYEES ) ;


ALTER TABLE PRODUCTS
       ADD  ( FOREIGN KEY (CATEGORY_ID)
                             REFERENCES CATEGORIES ) ;


ALTER TABLE PRODUCT_SUPPLIER
       ADD  ( FOREIGN KEY (SUPPLIER_ID)
                             REFERENCES SUPPLIERS ) ;


ALTER TABLE PRODUCT_SUPPLIER
       ADD  ( FOREIGN KEY (PRODUCT_ID)
                             REFERENCES PRODUCTS ) ;


ALTER TABLE PRODUCT_PRICES
       ADD  ( FOREIGN KEY (PRODUCT_ID)
                             REFERENCES PRODUCTS ) ;


ALTER TABLE PRODUCT_PRICES
       ADD  ( FOREIGN KEY (PROMOTION_ID)
                             REFERENCES PROMOTIONS ) ;


ALTER TABLE PRODUCT_INVENTORY
       ADD  ( FOREIGN KEY (PRODUCT_ID)
                             REFERENCES PRODUCTS ) ;


ALTER TABLE CUSTOMERS
       ADD  ( FOREIGN KEY (SALES_REP_ID)
                             REFERENCES EMPLOYEES ) ;


ALTER TABLE ORDERS
       ADD  ( FOREIGN KEY (EMPLOYEE_ID)
                             REFERENCES EMPLOYEES ) ;


ALTER TABLE ORDERS
       ADD  ( FOREIGN KEY (CUSTOMER_ID)
                             REFERENCES CUSTOMERS ) ;


ALTER TABLE ORDERS
       ADD  ( FOREIGN KEY (SHIPMENT_METHOD_ID)
                             REFERENCES SHIPMENT_METHOD ) ;


ALTER TABLE ORDERS
       ADD  ( FOREIGN KEY (PAYMENT_METHOD_ID)
                             REFERENCES PAYMENT_METHOD ) ;


ALTER TABLE ORDER_LINES
       ADD  ( FOREIGN KEY (ORDER_ID)
                             REFERENCES ORDERS ) ;


ALTER TABLE ORDER_LINES
       ADD  ( FOREIGN KEY (PRODUCT_ID)
                             REFERENCES PRODUCTS ) ;



